<no title> — CALCEPH - Fortran 77/90/95 language 3.4.1 documentation

    integer*8 peph
    integer res, nvalue
    character(len=CALCEPH_MAX_CONSTANTVALUE), allocatable :: mission_units
    character(len=CALCEPH_MAX_CONSTANTVALUE) svalue

    res = f90calceph_open(peph, "example1.dat")
    if (res.eq.1) then
         ! get the number of values
         nvalue = calceph_getconstantss(peph, "MISSION_UNITS", svalue)
         ! fill the array
         allocate(mission_units(1:nvalue))
         res = calceph_getconstantvs(peph, "MISSION_UNITS", mission_units, nvalue)
         write(*,*) mission_units

      call f90calceph_close(peph)
    endif